// Copyright (C) 2014-2018  GeometryFactory Sarl
//
// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 3 of the License,
// or (at your option) any later version.
//
// Licensees holding a valid commercial license may use this file in
// accordance with the commercial license agreement provided with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// $URL$
// $Id$
// SPDX-License-Identifier: LGPL-3.0+
//

#ifndef CGAL_SURFACE_MESH_FWD_H
#define CGAL_SURFACE_MESH_FWD_H

/// \file Surface_mesh_fwd.h
/// Forward declarations of the Surface_mesh package.

#ifndef DOXYGEN_RUNNING
namespace CGAL {

// fwdS for the public interface
template<typename K>
class Surface_mesh;

  
} // CGAL
#endif

#endif /* CGAL_SURFACE_MESH_FWD_H */


